CountryCodeFormat enum
Defines the format requirement for country codes in phone number validation.
Values
- required → const CountryCodeFormat
-
The country code is mandatory (e.g., "+1 123-456-7890").
- optional → const CountryCodeFormat
-
The country code is optional (e.g., "123-456-7890" or "+1 123-456-7890" are both valid).
- none → const CountryCodeFormat
-
The country code is not allowed (e.g., "123-456-7890" is valid, but "+1 123-456-7890" is not).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CountryCodeFormat> - A constant List of the values in this enum, in order of their declaration.